==> Qt5.6.3-macOS-x86_64-AppleClang6.1.0-20191202.tar.xz: Qt5.6.3-macOS-x86_64-AppleClang6.1.0-20191202/lib/cmake/Qt5WebEngineWidgets/Qt5WebEngineWidgetsConfig.cmake <==

if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5WebEngineWidgets_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5WebEngineWidgets_VERSION instead.
set(Qt5WebEngineWidgets_VERSION_STRING 5.6.3)

set(Qt5WebEngineWidgets_LIBRARIES Qt5::WebEngineWidgets)

macro(_qt5_WebEngineWidgets_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::WebEngineWidgets\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

macro(_populate_WebEngineWidgets_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::WebEngineWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set(imported_location "${_qt5WebEngineWidgets_install_prefix}/lib/${LIB_LOCATION}")
    _qt5_WebEngineWidgets_check_file_exists(${imported_location})
    set_target_properties(Qt5::WebEngineWidgets PROPERTIES
        "INTERFACE_LINK_LIBRARIES" "${_Qt5WebEngineWidgets_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5WebEngineWidgets_LIB_DEPENDENCIES}"
    )

endmacro()

if (NOT TARGET Qt5::WebEngineWidgets)

    set(_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS
      "${_qt5WebEngineWidgets_install_prefix}/lib/QtWebEngineWidgets.framework"
      "${_qt5WebEngineWidgets_install_prefix}/lib/QtWebEngineWidgets.framework/Headers"
    )
    set(Qt5WebEngineWidgets_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS})
        _qt5_WebEngineWidgets_check_file_exists(${_dir})
    endforeach()


    set(Qt5WebEngineWidgets_INCLUDE_DIRS ${_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS})

    set(Qt5WebEngineWidgets_DEFINITIONS -DQT_WEBENGINEWIDGETS_LIB)
    set(Qt5WebEngineWidgets_COMPILE_DEFINITIONS QT_WEBENGINEWIDGETS_LIB)
    set(_Qt5WebEngineWidgets_MODULE_DEPENDENCIES "WebEngineCore;Quick;Widgets;Gui;Network;Core")


    set(_Qt5WebEngineWidgets_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5WebEngineWidgets_FIND_REQUIRED)
        set(_Qt5WebEngineWidgets_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5WebEngineWidgets_FIND_DEPENDENCIES_QUIET)
    if (Qt5WebEngineWidgets_FIND_QUIETLY)
        set(_Qt5WebEngineWidgets_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5WebEngineWidgets_FIND_VERSION_EXACT)
    if (Qt5WebEngineWidgets_FIND_VERSION_EXACT)
        set(_Qt5WebEngineWidgets_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5WebEngineWidgets_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5WebEngineWidgets_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                5.6.3 ${_Qt5WebEngineWidgets_FIND_VERSION_EXACT}
                ${_Qt5WebEngineWidgets_DEPENDENCIES_FIND_QUIET}
                ${_Qt5WebEngineWidgets_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5WebEngineWidgets_FOUND False)
            return()
        endif()

        list(APPEND Qt5WebEngineWidgets_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5WebEngineWidgets_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5WebEngineWidgets_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5WebEngineWidgets_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5WebEngineWidgets_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5WebEngineWidgets_LIB_DEPENDENCIES "Qt5::WebEngineCore;Qt5::Quick;Qt5::Widgets;Qt5::Gui;Qt5::Network;Qt5::Core")


    add_library(Qt5::WebEngineWidgets SHARED IMPORTED)
    set_property(TARGET Qt5::WebEngineWidgets PROPERTY FRAMEWORK 1)

    set_property(TARGET Qt5::WebEngineWidgets PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::WebEngineWidgets PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_WEBENGINEWIDGETS_LIB)

    _populate_WebEngineWidgets_target_properties(RELEASE "QtWebEngineWidgets.framework/QtWebEngineWidgets" "" )




    file(GLOB pluginTargets "${CMAKE_CURRENT_LIST_DIR}/Qt5WebEngineWidgets_*Plugin.cmake")

    macro(_populate_WebEngineWidgets_plugin_properties Plugin Configuration PLUGIN_LOCATION)
        set_property(TARGET Qt5::${Plugin} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

        set(imported_location "${_qt5WebEngineWidgets_install_prefix}/plugins/${PLUGIN_LOCATION}")
        _qt5_WebEngineWidgets_check_file_exists(${imported_location})
        set_target_properties(Qt5::${Plugin} PROPERTIES
            "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        )
    endmacro()

    if (pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()




_qt5_WebEngineWidgets_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5WebEngineWidgetsConfigVersion.cmake")

endif()

==> Qt5.9.9-macOS-x86_64-AppleClang10.0.1-20191220.tar.xz: Qt5.9.9-macOS-x86_64-AppleClang10.0.1-20191220/lib/cmake/Qt5WebEngineWidgets/Qt5WebEngineWidgetsConfig.cmake <==

if (CMAKE_VERSION VERSION_LESS 2.8.3)
    message(FATAL_ERROR "Qt 5 requires at least CMake version 2.8.3")
endif()

get_filename_component(_qt5WebEngineWidgets_install_prefix "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# For backwards compatibility only. Use Qt5WebEngineWidgets_VERSION instead.
set(Qt5WebEngineWidgets_VERSION_STRING 5.9.9)

set(Qt5WebEngineWidgets_LIBRARIES Qt5::WebEngineWidgets)

macro(_qt5_WebEngineWidgets_check_file_exists file)
    if(NOT EXISTS "${file}" )
        message(FATAL_ERROR "The imported target \"Qt5::WebEngineWidgets\" references the file
   \"${file}\"
but this file does not exist.  Possible reasons include:
* The file was deleted, renamed, or moved to another location.
* An install or uninstall procedure did not complete successfully.
* The installation package was faulty and contained
   \"${CMAKE_CURRENT_LIST_FILE}\"
but not all the files it references.
")
    endif()
endmacro()

macro(_populate_WebEngineWidgets_target_properties Configuration LIB_LOCATION IMPLIB_LOCATION)
    set_property(TARGET Qt5::WebEngineWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

    set(imported_location "${_qt5WebEngineWidgets_install_prefix}/lib/${LIB_LOCATION}")
    _qt5_WebEngineWidgets_check_file_exists(${imported_location})
    set_target_properties(Qt5::WebEngineWidgets PROPERTIES
        "INTERFACE_LINK_LIBRARIES" "${_Qt5WebEngineWidgets_LIB_DEPENDENCIES}"
        "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        # For backward compatibility with CMake < 2.8.12
        "IMPORTED_LINK_INTERFACE_LIBRARIES_${Configuration}" "${_Qt5WebEngineWidgets_LIB_DEPENDENCIES}"
    )

endmacro()

if (NOT TARGET Qt5::WebEngineWidgets)

    set(_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS
      "${_qt5WebEngineWidgets_install_prefix}/lib/QtWebEngineWidgets.framework"
      "${_qt5WebEngineWidgets_install_prefix}/lib/QtWebEngineWidgets.framework/Headers"
    )
    set(Qt5WebEngineWidgets_PRIVATE_INCLUDE_DIRS "")
    include("${CMAKE_CURRENT_LIST_DIR}/ExtraSourceIncludes.cmake" OPTIONAL)

    foreach(_dir ${_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS})
        _qt5_WebEngineWidgets_check_file_exists(${_dir})
    endforeach()


    set(Qt5WebEngineWidgets_INCLUDE_DIRS ${_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS})

    set(Qt5WebEngineWidgets_DEFINITIONS -DQT_WEBENGINEWIDGETS_LIB)
    set(Qt5WebEngineWidgets_COMPILE_DEFINITIONS QT_WEBENGINEWIDGETS_LIB)
    set(_Qt5WebEngineWidgets_MODULE_DEPENDENCIES "WebEngineCore;Quick;PrintSupport;Widgets;Gui;Network;Core")


    set(Qt5WebEngineWidgets_OWN_PRIVATE_INCLUDE_DIRS ${Qt5WebEngineWidgets_PRIVATE_INCLUDE_DIRS})

    set(_Qt5WebEngineWidgets_FIND_DEPENDENCIES_REQUIRED)
    if (Qt5WebEngineWidgets_FIND_REQUIRED)
        set(_Qt5WebEngineWidgets_FIND_DEPENDENCIES_REQUIRED REQUIRED)
    endif()
    set(_Qt5WebEngineWidgets_FIND_DEPENDENCIES_QUIET)
    if (Qt5WebEngineWidgets_FIND_QUIETLY)
        set(_Qt5WebEngineWidgets_DEPENDENCIES_FIND_QUIET QUIET)
    endif()
    set(_Qt5WebEngineWidgets_FIND_VERSION_EXACT)
    if (Qt5WebEngineWidgets_FIND_VERSION_EXACT)
        set(_Qt5WebEngineWidgets_FIND_VERSION_EXACT EXACT)
    endif()

    set(Qt5WebEngineWidgets_EXECUTABLE_COMPILE_FLAGS "")

    foreach(_module_dep ${_Qt5WebEngineWidgets_MODULE_DEPENDENCIES})
        if (NOT Qt5${_module_dep}_FOUND)
            find_package(Qt5${_module_dep}
                5.9.9 ${_Qt5WebEngineWidgets_FIND_VERSION_EXACT}
                ${_Qt5WebEngineWidgets_DEPENDENCIES_FIND_QUIET}
                ${_Qt5WebEngineWidgets_FIND_DEPENDENCIES_REQUIRED}
                PATHS "${CMAKE_CURRENT_LIST_DIR}/.." NO_DEFAULT_PATH
            )
        endif()

        if (NOT Qt5${_module_dep}_FOUND)
            set(Qt5WebEngineWidgets_FOUND False)
            return()
        endif()

        list(APPEND Qt5WebEngineWidgets_INCLUDE_DIRS "${Qt5${_module_dep}_INCLUDE_DIRS}")
        list(APPEND Qt5WebEngineWidgets_PRIVATE_INCLUDE_DIRS "${Qt5${_module_dep}_PRIVATE_INCLUDE_DIRS}")
        list(APPEND Qt5WebEngineWidgets_DEFINITIONS ${Qt5${_module_dep}_DEFINITIONS})
        list(APPEND Qt5WebEngineWidgets_COMPILE_DEFINITIONS ${Qt5${_module_dep}_COMPILE_DEFINITIONS})
        list(APPEND Qt5WebEngineWidgets_EXECUTABLE_COMPILE_FLAGS ${Qt5${_module_dep}_EXECUTABLE_COMPILE_FLAGS})
    endforeach()
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_PRIVATE_INCLUDE_DIRS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_COMPILE_DEFINITIONS)
    list(REMOVE_DUPLICATES Qt5WebEngineWidgets_EXECUTABLE_COMPILE_FLAGS)

    set(_Qt5WebEngineWidgets_LIB_DEPENDENCIES "Qt5::WebEngineCore;Qt5::Quick;Qt5::PrintSupport;Qt5::Widgets;Qt5::Gui;Qt5::Network;Qt5::Core")


    add_library(Qt5::WebEngineWidgets SHARED IMPORTED)
    set_property(TARGET Qt5::WebEngineWidgets PROPERTY FRAMEWORK 1)

    set_property(TARGET Qt5::WebEngineWidgets PROPERTY
      INTERFACE_INCLUDE_DIRECTORIES ${_Qt5WebEngineWidgets_OWN_INCLUDE_DIRS})
    set_property(TARGET Qt5::WebEngineWidgets PROPERTY
      INTERFACE_COMPILE_DEFINITIONS QT_WEBENGINEWIDGETS_LIB)

    set(_Qt5WebEngineWidgets_PRIVATE_DIRS_EXIST TRUE)
    foreach (_Qt5WebEngineWidgets_PRIVATE_DIR ${Qt5WebEngineWidgets_OWN_PRIVATE_INCLUDE_DIRS})
        if (NOT EXISTS ${_Qt5WebEngineWidgets_PRIVATE_DIR})
            set(_Qt5WebEngineWidgets_PRIVATE_DIRS_EXIST FALSE)
        endif()
    endforeach()

    if (_Qt5WebEngineWidgets_PRIVATE_DIRS_EXIST
        AND NOT CMAKE_VERSION VERSION_LESS 3.0.0 )
        add_library(Qt5::WebEngineWidgetsPrivate INTERFACE IMPORTED)
        set_property(TARGET Qt5::WebEngineWidgetsPrivate PROPERTY
            INTERFACE_INCLUDE_DIRECTORIES ${Qt5WebEngineWidgets_OWN_PRIVATE_INCLUDE_DIRS}
        )
        set(_Qt5WebEngineWidgets_PRIVATEDEPS)
        foreach(dep ${_Qt5WebEngineWidgets_LIB_DEPENDENCIES})
            if (TARGET ${dep}Private)
                list(APPEND _Qt5WebEngineWidgets_PRIVATEDEPS ${dep}Private)
            endif()
        endforeach()
        set_property(TARGET Qt5::WebEngineWidgetsPrivate PROPERTY
            INTERFACE_LINK_LIBRARIES Qt5::WebEngineWidgets ${_Qt5WebEngineWidgets_PRIVATEDEPS}
        )
    endif()

    _populate_WebEngineWidgets_target_properties(RELEASE "QtWebEngineWidgets.framework/QtWebEngineWidgets" "" )




    file(GLOB pluginTargets "${CMAKE_CURRENT_LIST_DIR}/Qt5WebEngineWidgets_*Plugin.cmake")

    macro(_populate_WebEngineWidgets_plugin_properties Plugin Configuration PLUGIN_LOCATION)
        set_property(TARGET Qt5::${Plugin} APPEND PROPERTY IMPORTED_CONFIGURATIONS ${Configuration})

        set(imported_location "${_qt5WebEngineWidgets_install_prefix}/plugins/${PLUGIN_LOCATION}")
        _qt5_WebEngineWidgets_check_file_exists(${imported_location})
        set_target_properties(Qt5::${Plugin} PROPERTIES
            "IMPORTED_LOCATION_${Configuration}" ${imported_location}
        )
    endmacro()

    if (pluginTargets)
        foreach(pluginTarget ${pluginTargets})
            include(${pluginTarget})
        endforeach()
    endif()




_qt5_WebEngineWidgets_check_file_exists("${CMAKE_CURRENT_LIST_DIR}/Qt5WebEngineWidgetsConfigVersion.cmake")

endif()
